MethodChannelSmsAutoFillPlus class

Inheritance

Properties

hashCode int
The hash code for this object.
no setterinherited
methodChannel MethodChannel
final
results Stream<OtpResult>
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getAppSignature() Future<String>
override
getDiagnostics() Future<Map<String, dynamic>?>
override
listenForCode({OtpParser? parser, AutofillStrategy strategy = AutofillStrategy.auto, String? senderPhoneNumber}) Future<void>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
requestPhoneHint() Future<String?>
override
simulateMessage(String message) Future<void>
override
toString() String
A string representation of this object.
inherited
unregisterListener() Future<void>
override

Operators

operator ==(Object other) bool
The equality operator.
inherited